@@ -13,7 +13,9 @@ def BouncedMiddleware(get_response):
         async def middleware(request):
             # Do something here!
             if hasattr(request, "auth"):
+                bounced = Bounced.from_auth(request.auth)
                 request.bounced = Bounced.from_auth(request.auth)
+                setattr(request, "user", bounced.user)
             elif hasattr(request, "session"):
                 app = await sync_to_async(get_session_app)()
                 request.bounced = Bounced.from_session_app_and_user(app, request.user)
@@ -26,7 +28,9 @@ def BouncedMiddleware(get_response):
         def middleware(request):
             # Do something here!
             if hasattr(request, "auth"):
-                request.bounced = Bounced(request.auth)
+                bounced = Bounced.from_auth(request.auth)
+                request.bounced = bounced
+                setattr(request, "user", bounced.user)
             elif hasattr(request, "session"):
                 app = get_session_app()
                 request.bounced = Bounced.from_session_app_and_user(app, request.user)
