@@ -28,10 +28,15 @@ class BouncerChannelMiddleware:
         # Look up user from query string (you should also do things like
         # check it's a valid user ID, or if scope["user"] is already populated)
         if "auth" in scope:
-            scope["bounced"]= Bounced.from_auth(scope["auth"])
+            bounced =  Bounced.from_auth(scope["auth"])
+            scope["bounced"]= bounced
+            scope["user"] = bounced.user
+            scope["app"] = bounced.app
         elif "session" in scope:
             app = await sync_to_async(get_session_app)()
-            scope["bounced"] = Bounced.from_session_app_and_user(app, scope["user"])
+            bounced = Bounced.from_session_app_and_user(app, scope["user"])
+            scope["bounced"] = bounced
+            scope["app"] = bounced.app
         else:
             scope["bounced"] = None
         return await self.app(scope, receive, send)
\ No newline at end of file
