@@ -2,11 +2,9 @@ import logging
 import jwt
 import json
 import base64
-from .settings import get_active_settings
 import re
 from django.core.exceptions import ImproperlyConfigured, PermissionDenied
-
-active_settings = get_active_settings()
+from django.conf import settings
 
 
 logger = logging.getLogger(__name__)
@@ -20,10 +18,10 @@ def decode_token(token):
 
     payload_enc += '=' * (-len(payload_enc) % 4)  # add padding
     payload = json.loads(base64.b64decode(payload_enc).decode("utf-8"))
-    algorithms = [active_settings.key_type]
-    public_key = active_settings.public_key
+    algorithms = [settings.LOK["KEY_TYPE"]]
+    public_key = settings.LOK["PUBLIC_KEY"]
     if not public_key:
-        raise ImproperlyConfigured('Missing setting HERRE PUBLIC_KEY')
+        raise ImproperlyConfigured('Missing setting LOK PUBLIC_KEY')
     
     decoded = jwt.decode(token, public_key, algorithms=algorithms)
     return decoded
